# Vampire Analysis 

Vampire Analysis Tool reads microscope images of cells and catagorize each cells based on its morphological characteristics.
This tool is created to better understand the morphological features of the cells.